/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package cnam.webProj.ui.user;

import cnam.webProj.model.ForumGroup;
import cnam.webProj.model.ForumUser;
import cnam.webProj.service.UserService;
import cnam.webProj.ui.UserConnection;
import javax.enterprise.context.RequestScoped;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;
import javax.validation.constraints.Size;

/**
 *
 * @author rosmord
 */
@Named
@RequestScoped
public class UserCreateBean {

    @Inject // or @EJB
    UserService userService;
    
    @Inject
    UserConnection userConnection;

    private String login = "";

    @Size(min = 4)
    private String password1 = "";

    @Size(min = 4)
    private String password2 = "";
    

    public boolean getHasUsers() {
        return userService.hasUsers();
    }

    public String getLogin() {
        return login;
    }

    public void setLogin(String login) {
        this.login = login;
    }

    public String getPassword1() {
        return password1;
    }

    public void setPassword1(String password1) {
        this.password1 = password1;
    }

    public String getPassword2() {
        return password2;
    }

    public void setPassword2(String password2) {
        this.password2 = password2;
    }

    /**
     * Is it possible to create a new user. This is true if either
     * <ul>
     * <li> there is no user at all (first user is then admin)
     * <li> or if the current user is and administrator.
     * </ul>
     *
     * @return
     */
    public boolean getCanCreateUser() {
        return (userConnection.getHasAdminRights() || !userService.hasUsers());
    }

    /**
     * Create a new user. Is only possible if {@link #getCanCreateUser()} is
     * true.
     *
     * <p> If no user existed, the newly created user will automatically be logged in.
     * @return
     */
    public String create() {
        boolean ok;
        boolean isFirstUser= ! userService.hasUsers();
        
        String errorMessage = "";
        if (getCanCreateUser()) {
            if (!password1.equals(password2)) {
                ok = false;
                errorMessage = "passwords must match";
            } else {
                ok= true;
            }
        } else {
            ok = false;
            errorMessage = "sorry, you can't create users.";
        }
        if (ok) {
            ForumGroup group= ForumGroup.USER;
            // To avoid problems, we enforce admin group for the first user.
            if (isFirstUser) {
                group= ForumGroup.ADMIN;
            }
            ForumUser newUser = userService.create(login, password1, group);
            // We automatically connect the first user.
            if (isFirstUser) {
                userConnection.setCurrentUser(newUser);                
            }
            String message= "User " + login + " created";
            System.err.println(message);
            FacesContext.getCurrentInstance().addMessage(null,
                    new FacesMessage(FacesMessage.SEVERITY_INFO, message, message));
            return "success";
        } else {
            FacesContext.getCurrentInstance().addMessage(null,
                    new FacesMessage(FacesMessage.SEVERITY_ERROR, errorMessage, errorMessage));
            System.err.println(errorMessage);
            return "failure";
        }
    }

}
